summaryrefslogtreecommitdiffstats
path: root/src/include/sys
diff options
context:
space:
mode:
authorPatrick Williams <iawillia@us.ibm.com>2012-11-13 15:36:05 -0600
committerA. Patrick Williams III <iawillia@us.ibm.com>2012-11-14 15:45:36 -0600
commit073d82a61ee7ce0ec4522c18ce92cd93537025db (patch)
tree382b3db4c6032fb83b2e1c7e9f50eb6c0507fb5b /src/include/sys
parentf5fc4c94d84ed3a5263d4139cb09179a5722f382 (diff)
downloadtalos-hostboot-073d82a61ee7ce0ec4522c18ce92cd93537025db.tar.gz
talos-hostboot-073d82a61ee7ce0ec4522c18ce92cd93537025db.zip
Expand memory footprint to full 8MB cache.
If fake PNOR isn't being used, we can expand our memory space to the full 8MB cache. There will be follow up work with RTC: 49137 to support 4MB degraded caches for bring-up. Change-Id: I1248efa37965f39ebab62aae556349c34aa24b66 RTC: 47356 Reviewed-on: http://gfw160.austin.ibm.com:8080/gerrit/2319 Tested-by: Jenkins Server Reviewed-by: Melissa J. Connell <missyc@us.ibm.com> Reviewed-by: ADAM R. MUHLE <armuhle@us.ibm.com> Reviewed-by: A. Patrick Williams III <iawillia@us.ibm.com>
Diffstat (limited to 'src/include/sys')
-rw-r--r--src/include/sys/mm.h14
1 files changed, 11 insertions, 3 deletions
diff --git a/src/include/sys/mm.h b/src/include/sys/mm.h
index 34a60fc20..1b21816a8 100644
--- a/src/include/sys/mm.h
+++ b/src/include/sys/mm.h
@@ -96,12 +96,20 @@ int mm_remove_pages(PAGE_REMOVAL_OPS i_op, void* i_vaddr, uint64_t i_size);
*/
int mm_set_permission(void* va, uint64_t size, uint64_t access_type);
+enum MM_EXTEND_SIZE
+{
+ MM_EXTEND_FULL_CACHE, //< Extend memory to include full cache (8mb).
+ MM_EXTEND_REAL_MEMORY, //< Extend memory into real mainstore.
+};
+
/** @fn mm_extend()
* @brief System call to extend Memory to 32MEG
*
* @return int - 0 for successful extension of memory, non-zero otherwise
*/
-int mm_extend(void);
+int mm_extend(MM_EXTEND_SIZE i_size = MM_EXTEND_REAL_MEMORY);
/** @fn mm_linear_map()
* @brief Allocates a block of memory of the given size at a specified
@@ -126,7 +134,7 @@ int mm_linear_map(void *i_paddr, uint64_t i_size);
void mm_icache_invalidate(void * i_addr, size_t i_cpu_word_count);
/** @fn mm_virt_to_phys()
- * @brief System call to return the physical address backing a
+ * @brief System call to return the physical address backing a
* virtual address
*
* @param[in] i_vaddr - Virtual address to translate
@@ -96,12 +96,20 @@ int mm_remove_pages(PAGE_REMOVAL_OPS i_op, void* i_vaddr, uint64_t i_size);
/** @fn mm_extend()
- * @brief System call to extend Memory to 32MEG
+ * @brief System call to extend memory.
+ *
+ * @param[in] i_size - Amount to extend memory by.
*
* @return int - 0 for successful extension of memory, non-zero otherwise
OpenPOWER on IntegriCloud